"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.automockEnums = automockEnums;
exports.automockScalars = automockScalars;
exports.defaultAutomocks = exports.scalarMocks = void 0;

var _casual = _interopRequireDefault(require("casual"));

var _graphql = require("graphql");

var _list = require("./list");

var _relay = require("./relay");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function automockEnums(parentType, field) {
  const nullableType = (0, _graphql.getNullableType)(field.type);

  if (!(nullableType instanceof _graphql.GraphQLEnumType)) {
    return;
  }

  const values = nullableType.getValues().map(value => value.value);
  return () => values[_casual.default.integer(0, values.length - 1)];
} // TODO Use `faker` once v5 is released


const scalarMocks = {
  Boolean: () => _casual.default.boolean,
  ID: () => _casual.default.uuid,
  Int: () => _casual.default.integer(-100, 100),
  Float: () => _casual.default.double(-100, 100),
  String: () => _casual.default.string
};
exports.scalarMocks = scalarMocks;

function automockScalars(scalarMocks) {
  return (parentType, field) => {
    const nullableType = (0, _graphql.getNullableType)(field.type);
    const scalarMock = scalarMocks[nullableType.name];

    if (scalarMock) {
      return scalarMock;
    }
  };
}

const defaultAutomocks = [automockScalars(scalarMocks), automockEnums, _list.automockLists, _relay.automockRelay];
exports.defaultAutomocks = defaultAutomocks;
//# sourceMappingURL=automock.js.map